Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/pixel_framebuf_simpletest.py
    :caption: examples/pixel_framebuf_simpletest.py
    :linenos:

.. literalinclude:: ../examples/pixel_framebuf_dotstar_simpletest.py
    :caption: examples/pixel_framebuf_dotstar_simpletest.py
    :linenos:

Other Examples
---------------

Some other examples for using this library

.. literalinclude:: ../examples/pixel_framebuf_32x8_test.py
    :caption: examples/pixel_framebuf_32x8_test.py
    :linenos:

.. literalinclude:: ../examples/pixel_framebuf_16x16_animation.py
    :caption: examples/pixel_framebuf_16x16_animation.py
    :linenos:
